@@ -2,7 +2,7 @@ from esmecata.annotation import rest_query_uniprot_to_retrieve_function, sparql_
                                 search_already_annotated_protein, query_uniprot_annotation_rest, query_uniprot_annotation_sparql, \
                                 propagate_annotation_in_cluster
 
-ANOTATIONS = {'Q7CGB6': ['Protein translocase subunit SecA (EC 7.4.2.8)', True,
+ANOTATIONS = {'Q7CGB6': ['Protein translocase subunit SecA', True,
             ['GO:0031522','GO:0005829','GO:0005887','GO:0015462','GO:0005524','GO:0046872','GO:0065002','GO:0017038','GO:0006605','GO:0043952','GO:0008564'],
             ['7.4.2.8'],
             ['IPR027417','IPR004027','IPR000185','IPR020937','IPR011115','IPR014018','IPR011130','IPR011116','IPR036266','IPR036670','IPR014001','IPR044722'],
@@ -14,7 +14,7 @@ UP000119554_ANOTATIONS = {'O91464': ['Genome polyprotein', True,
                                 'GO:0005216', 'GO:0005524', 'GO:0006351', 'GO:0016021', 'GO:0016887',
                                 'GO:0018144', 'GO:0019028', 'GO:0019062', 'GO:0039522', 'GO:0039618',
                                 'GO:0039657', 'GO:0039690', 'GO:0039694', 'GO:0039707', 'GO:0044162',
-                                'GO:0044178', 'GO:0044385', 'GO:0046718', 'GO:0051259'],
+                                'GO:0044178', 'GO:0044385', 'GO:0046718', 'GO:0051259', 'GO:0006508'],
                             ['2.7.7.48', '3.6.4.13'],
                             ['IPR000199', 'IPR000605', 'IPR001205', 'IPR001676', 'IPR004004',
                             'IPR007053', 'IPR007094', 'IPR009003', 'IPR014759', 'IPR027417',
@@ -57,8 +57,7 @@ def test_search_already_annotated_protein():
 def test_query_uniprot_annotation_rest():
     protein_to_search_on_uniprots = ['Q7CGB6']
     output_dict = {}
-    beta = None
-    output_dict = query_uniprot_annotation_rest(protein_to_search_on_uniprots, beta, output_dict)
+    output_dict = query_uniprot_annotation_rest(protein_to_search_on_uniprots, output_dict)
     compare_annotation_dict(ANOTATIONS, output_dict)
 
 
